@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.65_01'; # TRIAL VERSION
+our $VERSION = '0.66_01'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -545,7 +545,7 @@ sub _have_pm
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.65_01'; # TRIAL VERSION
+our $VERSION = '0.66_01'; # TRIAL VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -561,7 +561,7 @@ package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.65_01'; # TRIAL VERSION
+our $VERSION = '0.66_01'; # TRIAL VERSION
 
 sub new
 {
@@ -663,7 +663,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.65_01
+version 0.66_01
 
 =head1 SYNOPSIS
 
@@ -1957,7 +1957,7 @@ pull request on this project's GitHub repository:
 L<https://github.com/Perl5-FFI/FFI-Platypus/pulls>
 
 This project is developed using L<Dist::Zilla>.  The project's git 
-repository also comes with the C<Build.PL> file necessary 
+repository also comes with the C<Makefile.PL> file necessary 
 for building, testing (and even installing if necessary) without 
 L<Dist::Zilla>.  Please keep in mind though that these files are 
 generated so if changes need to be made to those files they should be 
@@ -1990,9 +1990,9 @@ that is normally automatically built by C<./Build test>.  If you prefer
 to use C<prove> or run tests directly, you can use the C<./Build 
 libtest> command to build it.  Example:
 
- % perl Build.PL
- % ./Build
- % ./Build libtest
+ % perl Makefile.PL
+ % make
+ % make mymm_test
  % prove -bv t
  # or an individual test
  % perl -Mblib t/ffi_platypus_memory.t
@@ -2001,26 +2001,6 @@ The build process also respects these environment variables:
 
 =over 4
 
-=item FFI_PLATYPUS_DEBUG
-
-Build the XS code portion of Platypus with -g3 instead of what ever 
-optimizing flags that your Perl normally uses.  This is useful if you 
-need to debug the C or XS code that comes with Platypus, but do not have 
-a debugging Perl.
-
- % env FFI_PLATYPUS_DEBUG=1 perl Build.PL
- 
- 
- DEBUG:
-   - $Config{lddlflags} = -shared -O2 -L/usr/local/lib -fstack-protector
-   + $Config{lddlflags} = -shared -g3 -L/usr/local/lib -fstack-protector
-   - $Config{optimize} = -O2
-   + $Config{optimize} = -g3
- 
- 
- Created MYMETA.yml and MYMETA.json
- Creating new 'Build' script for 'FFI-Platypus' version '0.10'
-
 =item FFI_PLATYPUS_DEBUG_FAKE32
 
 When building Platypus on 32 bit Perls, it will use the L<Math::Int64> C 
@@ -2028,15 +2008,14 @@ API and make L<Math::Int64> a prerequisite.  Setting this environment
 variable will force Platypus to build with both of those options on a 64 
 bit Perl as well.
 
- % env FFI_PLATYPUS_DEBUG_FAKE32=1 perl Build.PL
- 
- 
+ % env FFI_PLATYPUS_DEBUG_FAKE32=1 perl Makefile.PL
  DEBUG_FAKE32:
-   + making Math::Int64 a prerequisite (not normally done on 64 bit Perls)
-   + using Math::Int64's C API to manipulate 64 bit values (not normally done on 64 bit Perls)
- 
- Created MYMETA.yml and MYMETA.json
- Creating new 'Build' script for 'FFI-Platypus' version '0.10'
+   + making Math::Int64 a prereq
+   + Using Math::Int64's C API to manipulate 64 bit values
+ Generating a Unix-style Makefile
+ Writing Makefile for FFI::Platypus
+ Writing MYMETA.yml and MYMETA.json
+ %
 
 =item FFI_PLATYPUS_NO_ALLOCA
 
@@ -2046,17 +2025,14 @@ Platypus uses it responsibly to allocate small amounts of memory for
 argument type parameters, and does not use it to allocate large 
 structures like arrays or buffers.  If you prefer not to use C<alloca> 
 despite these precautions, then you can turn its use off by setting this 
-environment variable when you run C<Build.PL>:
+environment variable when you run C<Makefile.PL>:
 
- % env FFI_PLATYPUS_NO_ALLOCA=1 perl Build.PL
- 
- 
+ helix% env FFI_PLATYPUS_NO_ALLOCA=1 perl Makefile.PL 
  NO_ALLOCA:
    + alloca() will not be used, even if your platform supports it.
- 
- 
-  Created MYMETA.yml and MYMETA.json
-  Creating new 'Build' script for 'FFI-Platypus' version '0.10'
+ Generating a Unix-style Makefile
+ Writing Makefile for FFI::Platypus
+ Writing MYMETA.yml and MYMETA.json
 
 =back
 
